@@ -59,6 +59,14 @@ bool Controller::kmPlayerInstalled() {
     return isInstalled;
 }
 
+bool Controller::xTubeInstalled() {
+    bool isInstalled = false;
+    if (QFile::exists("/opt/usr/share/qmltube/qml/qmltube/xtube.js")) {
+        isInstalled = true;
+    }
+    return isInstalled;
+}
+
 void Controller::playVideo(const QString &url) {
 #ifdef Q_WS_MAEMO_5
     //    qDebug() << url;
