@@ -1,8 +1,14 @@
 /* Main view functions */
 
+var xTubeInstalled = false;
+
 function restoreSettings() {
     /* Restore the user's settings from the database */
 
+    if (Controller.xTubeInstalled()) {
+        Qt.include("xtube.js");
+        xTubeInstalled = true;
+    }
     Settings.initialize();
     Controller.setOrientation(Settings.getSetting("screenOrientation"));
     if (Controller.kmPlayerInstalled()) {
@@ -161,7 +167,7 @@ function loadDownloads() {
     windowView.incrementCurrentIndex();
 }
 
-function search(query) {
+function youtubeSearch(query) {
     /* Perform a YouTube search and open video list window */
 
     var videoFeed = ("http://gdata.youtube.com/feeds/api/videos?v=2&max-results=50&safeSearch=none&q="
@@ -169,6 +175,27 @@ function search(query) {
     loadVideos(videoFeed, "Search ('" + query + "')");
 }
 
+function search(query) {
+    /* Check if xTube is installed and parse the search query */
+
+    if (xTubeInstalled) {
+        var youjizz = /^yj:/i;
+        var xhamster = /^xh:/i;
+        if (youjizz.test(query)) {
+            youjizzSearch(query.substr(3));
+        }
+        else if (xhamster.test(query)) {
+            xhamsterSearch(query.substr(3));
+        }
+        else {
+            youtubeSearch(query);
+        }
+    }
+    else {
+        youtubeSearch(query);
+    }
+}
+
 function toggleMenu() {
     /* Show/hide the menu of the current view */
 
